matrices library

Classes

Matrix

Functions

derivative(Matrix activation(Matrix)) Matrix Function(Matrix)
finds the derivative function
dot(Matrix matrixA, Matrix matrixB) Matrix
dot product of two matrices
exponential(Matrix matrix) Matrix
exponential of a matrix
fill(num num, int row, int col) Matrix
Create a matrix with a num
leakyDeriv(Matrix matrix) Matrix
derivative of a leaky relu matrix
leakyRelu(Matrix matrix) Matrix
leaky relu of a matrix
linear(Matrix matrix) Matrix
linear of a matrix
linearDeriv(Matrix matrix) Matrix
derivative of a linear matrix
maxIndex(Matrix matrix) List<int>
Find the index of the maximum value in the matrix
maxValue(Matrix matrix) double
mean(Matrix matrix) double
mean of a matrix
minIndex(Matrix matrix) List<int>
Find the index of the maximum value in the matrix
minValue(Matrix matrix) double
oneHot(int value, int size) Matrix
one hot encoding of a matrix
power(Matrix matrix, int x) Matrix
scalar power of a matrix
randn(int row, int col, {double start = -1, double end = 1, int? seed}) Matrix
Create a matrix with random values
relu(Matrix matrix) Matrix
relu of a matrix
reluDeriv(Matrix matrix) Matrix
derivative of a relu matrix
sigmoid(Matrix matrix) Matrix
sigmoid of a matrix
sigmoidDeriv(Matrix matrix) Matrix
derivative of a sigmoid matrix
softmax(Matrix matrix) Matrix
Softmax of a matrix
softmaxDeriv(Matrix matrix) Matrix
derivative of a tanh matrix
sum(Matrix matrix, int axis) → dynamic
sum of a matrix
tanH(Matrix matrix) Matrix
tanh of a matrix
tanHDeriv(Matrix matrix) Matrix
derivative of a tanh matrix
toMatrix(List values) Matrix
converts a list to a matrix
zeros(int row, int col) Matrix
Create a matrix with zeros