utils
library
Functions
-
dot(Matrix matrixA, Matrix matrixB)
→ Matrix
-
dot product of two matrices
-
fill(num num, int row, int col)
→ Matrix
-
Create a matrix with a num
-
maxIndex(Matrix matrix)
→ List<int>
-
Find the index of the maximum value in the matrix
-
maxValue(Matrix matrix)
→ double
-
-
mean(Matrix matrix)
→ double
-
mean of a matrix
-
minIndex(Matrix matrix)
→ List<int>
-
Find the index of the maximum value in the matrix
-
minValue(Matrix matrix)
→ double
-
-
power(Matrix matrix, int x)
→ Matrix
-
scalar power of a matrix
-
randn(int row, int col, {double start = -1, double end = 1, int? seed})
→ Matrix
-
Create a matrix with random values
-
sum(Matrix matrix, int axis)
→ dynamic
-
sum of a matrix
-
toMatrix(List values)
→ Matrix
-
converts a list to a matrix
-
zeros(int row, int col)
→ Matrix
-
Create a matrix with zeros