Matrix class
Constructors
Properties
Methods
-
add(
Matrix matrixB) → Matrix - Add two matrices
-
clip(
double min, double max) → Matrix -
contains(
double value) → bool -
divide(
Matrix matrixB) → Matrix - Divide two matrices
-
dot(
Matrix matrixB) → Matrix - Dot product of two matrices
-
Dropout(
double rate) → Matrix -
empty(
) → void - Create an empty matrix
-
fill(
double num) → void - Fill the matrix with a specific number
-
generateDouble(
double min, double max, {int? seed}) → void - Fills the matrix with random doubles
-
generateInt(
int min, int max, {int? seed}) → void - Fills the matrix with random integers
-
getAt(
int row, int col) → double - Get the value of a matrix at a specific index
-
getDimensions(
) → List< int> - Gets the dimensions of the matrix
-
getMatrix(
) → List< List< double> > - Gets the matrix as a list
-
getSize(
) → List< int> - Gets the size of the matrix
-
hadamardProduct(
Matrix matrixB) → Matrix - Multiply two matrices
-
isEquivalent(
Matrix matrxiB) → bool - Check if two matrices are equivalent
-
join(
String s) → dynamic -
max(
) → double -
multiply(
double x) → Matrix - Multiply the matrix by a scalar
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
performFunction(
dynamic function(double)) → Matrix - Perform a function on the matrix
-
round(
[int places = 8]) → Matrix -
scalarDivide(
double x) → Matrix - Divide the matrix by a scalar
-
setAt(
int row, int col, {required double value}) → void - Set the value of a matrix at a specific index
-
subtract(
Matrix matrixB) → Matrix - Subtract two matrices
-
sum(
[int? axis = null]) → dynamic - sum the matrix
-
toString(
) → String -
A string representation of this object.
override
-
transpose(
) → Matrix - Transpose the matrix
Operators
-
operator *(
dynamic value) → Matrix -
operator +(
Matrix matrixB) → Matrix -
operator -(
dynamic value) → Matrix -
operator /(
dynamic value) → Matrix -
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
int index) → List -
operator []=(
int index, List< num> value) → void